@@ -77,12 +77,9 @@ class TestHelper(object):
         return value
 
     def getUniqueStringForField(self, model, field_name):
-        if django.VERSION > (1, 8):
-            field = [field for field in model._meta.get_fields()
-                     if field.name == field_name][0]
-            return self.getUniqueString(max_length=field.max_length)
-        else:
-            return self.getUniqueString(max_length=model._meta.get_field_by_name(field_name)[0].max_length)
+        field = [field for field in model._meta.get_fields()
+                 if field.name == field_name][0]
+        return self.getUniqueString(max_length=field.max_length)
 
 
 class BundleFormatImporter_1_1Tests(TestHelper, TestCaseWithScenarios):
