@@ -16,10 +16,12 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Lava Server.  If not, see <http://www.gnu.org/licenses/>.
 
+import os
 import yaml
 import urllib
 import logging
 import django
+import decimal
 from django.db import transaction
 from lava_results_app.models import (
     TestSuite,
@@ -31,7 +33,7 @@ from lava_results_app.models import (
 )
 from django.core.exceptions import MultipleObjectsReturned
 from lava_dispatcher.pipeline.action import Timeout
-# pylint: disable=no-member
+# pylint: disable=no-member,too-many-locals,too-many-nested-blocks
 
 if django.VERSION > (1, 10):
     from django.urls.exceptions import NoReverseMatch
@@ -73,11 +75,24 @@ def append_failure_comment(job, msg):
     logger.error(msg)
 
 
-def map_scanned_results(results, job):  # pylint: disable=too-many-branches,too-many-statements,too-many-return-statements
+def create_metadata_store(results, job, level):
+    if 'extra' not in results:
+        return None
+    stub = "%s-%s-%s.yaml" % (results['definition'], results['case'], level)
+    meta_filename = os.path.join(job.output_dir, 'metadata', stub)
+    if not os.path.exists(os.path.dirname(meta_filename)):
+        os.mkdir(os.path.dirname(meta_filename))
+    with open(meta_filename, 'a') as extra_store:
+        yaml.dump(results['extra'], extra_store)
+    return meta_filename
+
+
+def map_scanned_results(results, job, meta_filename):  # pylint: disable=too-many-branches,too-many-statements,too-many-return-statements
     """
     Sanity checker on the logged results dictionary
     :param results: results logged via the slave
     :param job: the current test job
+    :param meta_filename: YAML store for results metadata
     :return: False on error, else True
     """
     logger = logging.getLogger('dispatcher-master')
@@ -90,9 +105,14 @@ def map_scanned_results(results, job):  # pylint: disable=too-many-branches,too-
         append_failure_comment(job, "Missing some keys (\"definition\", \"case\" or \"result\") in %s" % results)
         return False
 
+    if 'extra' in results:
+        results['extra'] = meta_filename
+
     metadata_check = yaml.dump(results)
     if len(metadata_check) > 4096:  # bug 2471 - test_length unit test
-        append_failure_comment(job, "[%d] Error in handling results metadata %s" % (job.id, metadata_check))
+        msg = "[%d] Result metadata is too long. %s" % (job.id, metadata_check)
+        logger.error(msg)
+        append_failure_comment(job, msg)
         return False
 
     suite, created = TestSuite.objects.get_or_create(name=results["definition"], job=job)
@@ -169,19 +189,22 @@ def map_scanned_results(results, job):  # pylint: disable=too-many-branches,too-
         if result not in TestCase.RESULT_MAP:
             logger.warning("[%d] Unrecognised result: '%s' for test case '%s'", job.id, result, name)
             return False
-        TestCase.objects.create(
-            name=name,
-            suite=suite,
-            test_set=testset,
-            result=TestCase.RESULT_MAP[result],
-            measurement=measurement,
-            units=units
-        ).save()
+        try:
+            TestCase.objects.create(
+                name=name,
+                suite=suite,
+                test_set=testset,
+                result=TestCase.RESULT_MAP[result],
+                measurement=measurement,
+                units=units
+            ).save()
+        except decimal.InvalidOperation:
+            logger.exception("[%d] Unable to create test case %s", job.id, name)
     return True
 
 
 def _add_parameter_metadata(prefix, definition, dictionary, label):
-    if 'parameters' in definition:
+    if 'parameters' in definition and isinstance(definition['parameters'], dict):
         for paramkey, paramvalue in definition['parameters'].items():
             if paramkey == 'yaml_line':
                 continue
@@ -264,10 +287,8 @@ def _get_job_metadata(data):  # pylint: disable=too-many-branches,too-many-neste
 
 
 def _get_device_metadata(data):
-    hostname = data.get('hostname', None)
     devicetype = data.get('device_type', None)
     return {
-        'target.hostname': hostname,
         'target.device_type': devicetype
     }
 
@@ -354,6 +375,12 @@ def map_metadata(description, job):
     if description is None:
         logger.warning("[%s] skipping empty description", job.id)
         return
+    if not description_data:
+        logger.warning("[%s] skipping invalid description data", job.id)
+        return
+    if 'job' not in description_data:
+        logger.warning("[%s] skipping description without a job.", job.id)
+        return
     action_values = _get_job_metadata(description_data['job']['actions'])
     for key, value in action_values.items():
         if not key or not value:
@@ -403,6 +430,16 @@ def export_testcase(testcase):
     duration = float(actiondata.duration) if actiondata else ''
     timeout = actiondata.timeout if actiondata else ''
     level = actiondata.action_level if actiondata else None
+    metadata = dict(testcase.action_metadata) if testcase.action_metadata else {}
+    extra_source = []
+    extra_data = metadata.get('extra', None)
+    if extra_data and isinstance(extra_data, unicode) and os.path.exists(extra_data):
+        with open(metadata['extra'], 'r') as extra_file:
+            items = yaml.load(extra_file, Loader=yaml.CLoader)
+        # hide the !!python OrderedDict prefix from the output.
+        for key, value in items.items():
+            extra_source.append({key: value})
+        metadata['extra'] = extra_source
     casedict = {
         'name': str(testcase.name),
         'job': str(testcase.suite.job_id),
@@ -414,7 +451,7 @@ def export_testcase(testcase):
         'timeout': str(timeout),
         'logged': str(testcase.logged),
         'level': str(level),
-        'metadata': dict(testcase.action_metadata) if testcase.action_metadata else {},
+        'metadata': metadata,
         'url': str(testcase.get_absolute_url()),
     }
     return casedict
