@@ -112,15 +112,15 @@ urlpatterns = [
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+omit-result$', query_omit_result, name='lava.results.query_omit_result'),
     url(r'^query/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+include-result$', query_include_result, name='lava.results.query_include_result'),
     url(r'^query/get-query-groups$', query_group_list, name='query_group_list'),
-    url(r'^query/\+get-group-names$', get_query_group_names),
+    url(r'^query/\+get-group-names$', get_query_group_names, name='get_query_group_names'),
     url(r'^query/\+get-query-names$', get_query_names,
         name='lava.results.get_query_names'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)$', testjob, name='lava.results.testjob'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/csv$', testjob_csv, name='lava.results.testjob_csv'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/yaml$', testjob_yaml, name='lava.results.testjob_yaml'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/metadata$',
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)$', testjob, name='lava.results.testjob'),
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)/csv$', testjob_csv, name='lava.results.testjob_csv'),
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)/yaml$', testjob_yaml, name='lava.results.testjob_yaml'),
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)/metadata$',
         metadata_export, name='lava.results.job.metadata'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)$', suite, name='lava.results.suite'),
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)$', suite, name='lava.results.suite'),
     url(r'^chart$', chart_list, name='lava.results.chart_list'),
     url(r'^chart/\+add$', chart_add, name='lava.results.chart_add'),
     url(r'^chart/\+custom$', chart_custom, name='lava.results.chart_custom'),
@@ -151,8 +151,8 @@ urlpatterns = [
     url(r'^chart/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+settings-update$', settings_update, name='chart_settings_update'),
     url(r'^chart/(?P<name>[a-zA-Z0-9-_]+)/\+chart-query-order-update$', chart_query_order_update, name='chart_query_order_update'),
     url(r'^chart/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/(?P<result_id>\d+)/\+omit-result$', chart_omit_result, name='lava.results.chart_omit_result'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/(?P<ts>[-_a-zA-Z0-9.]+)/(?P<case>[-_a-zA-Z0-9.+]+)$', testset, name='lava.results.testset'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/csv$',
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/(?P<ts>[-_a-zA-Z0-9.]+)/(?P<case>[-_a-zA-Z0-9.+]+)$', testset, name='lava.results.testset'),
+    url(r'^(?P<job>[0-9]+|[0-9]+\.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/csv$',
         suite_csv, name='lava.results.suite_csv'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/stream/csv$',
         suite_csv_stream, name='lava.results.suite_csv_stream'),
