@@ -20,6 +20,7 @@
 
 # pylint: disable=wrong-import-order
 
+import errno
 import sys
 import fcntl
 import jinja2
@@ -45,12 +46,16 @@ from lava_scheduler_app.dbutils import (
     parse_job_description,
     select_device,
 )
-from lava_results_app.dbutils import map_scanned_results
+from lava_results_app.dbutils import map_scanned_results, create_metadata_store
 
 
 # pylint: disable=no-member,too-many-branches,too-many-statements,too-many-locals
 
-
+# Current version of the protocol
+# The slave does send the protocol version along with the HELLO and HELLO_RETRY
+# messages. If both version are not identical, the connection is refused by the
+# master.
+PROTOCOL_VERSION = 1
 # TODO constants to move into external files
 FD_TIMEOUT = 60
 TIMEOUT = 10
@@ -87,16 +92,21 @@ def get_env_string(filename):
     """
     Returns the string after checking for YAML errors which would cause issues later.
     """
-    if not os.path.exists(filename):
-        return ''
     logger = logging.getLogger('dispatcher-master')
-    env_str = str(open(filename, 'r').read())
     try:
-        yaml.load(env_str)
-    except yaml.ScannerError as exc:
-        logger.exception("%s is not valid YAML (%s) - skipping", filename, exc)
-        env_str = ''
-    return env_str
+        with open(filename, "r") as f_in:
+            env_str = f_in.read()
+        yaml.safe_load(env_str)
+        return env_str
+    except IOError as exc:
+        # This is ok if the file does not exist
+        if exc.errno == errno.ENOENT:
+            return ''
+        raise
+    except yaml.YAMLError as exc:
+        # Raise an IOError because the caller uses yaml.YAMLError for a
+        # specific usage. Allows here to specify the faulty filename.
+        raise IOError("", "Not a valid YAML file", filename)
 
 
 class Command(BaseCommand):
@@ -201,18 +211,6 @@ class Command(BaseCommand):
                 job_id, message)
             return
 
-        if message_lvl == "results":
-            try:
-                job = TestJob.objects.get(pk=job_id)
-            except TestJob.DoesNotExist:
-                self.logger.error("[%s] Unknown job id", job_id)
-                return
-            ret = map_scanned_results(results=message_msg, job=job)
-            if not ret:
-                self.logger.warning(
-                    "[%s] Unable to map scanned results: %s",
-                    job_id, message)
-
         # Clear filename
         if '/' in level or '/' in name:
             self.logger.error("[%s] Wrong level or name received, dropping the message", job_id)
@@ -233,6 +231,19 @@ class Command(BaseCommand):
             mkdir(os.path.dirname(filename))
             self.logs[job_id] = FileHandler(filename)
 
+        if message_lvl == "results":
+            try:
+                job = TestJob.objects.get(pk=job_id)
+            except TestJob.DoesNotExist:
+                self.logger.error("[%s] Unknown job id", job_id)
+                return
+            meta_filename = create_metadata_store(message_msg, job, level)
+            ret = map_scanned_results(results=message_msg, job=job, meta_filename=meta_filename)
+            if not ret:
+                self.logger.warning(
+                    "[%s] Unable to map scanned results: %s",
+                    job_id, message)
+
         # Mark the file handler as used
         # TODO: try to use a more pythonnic way
         self.logs[job_id].last_usage = time.time()
@@ -268,6 +279,18 @@ class Command(BaseCommand):
         # Handle the actions
         if action == 'HELLO' or action == 'HELLO_RETRY':
             self.logger.info("%s => %s", hostname, action)
+
+            # Check the protocol version
+            try:
+                slave_version = int(msg[2])
+            except (IndexError, ValueError):
+                self.logger.error("Invalid message from <%s> '%s'", hostname, msg)
+                return False
+            if slave_version != PROTOCOL_VERSION:
+                self.logger.error("<%s> using protocol v%d while master is using v%d",
+                                  hostname, slave_version, PROTOCOL_VERSION)
+                return False
+
             self.controler.send_multipart([hostname, 'HELLO_OK'])
             # If the dispatcher is known and sent an HELLO, means that
             # the slave has restarted
@@ -313,8 +336,6 @@ class Command(BaseCommand):
                 status = TestJob.INCOMPLETE
                 self.logger.info("[%d] %s => END with error %d", job_id, hostname, job_status)
                 self.logger.error("[%d] Error: %s", job_id, error_msg)
-                # Set the failure comment
-                TestJob.objects.filter(id=job_id).update(failure_comment=error_msg)
             else:
                 status = TestJob.COMPLETE
                 self.logger.info("[%d] %s => END", job_id, hostname)
@@ -413,7 +434,7 @@ class Command(BaseCommand):
             else:
                 device = select_device(job, self.dispatchers)
                 if not device:
-                    return False
+                    return
                 # selecting device can change the job
                 job = TestJob.objects.get(id=job.id)
                 self.logger.info("[%d] Assigning %s device", job.id, device)
@@ -423,7 +444,7 @@ class Command(BaseCommand):
                         msg = "Infrastructure error: Invalid worker information"
                         self.logger.error("[%d] %s", job.id, msg)
                         fail_job(job, msg, TestJob.INCOMPLETE)
-                        return False
+                        return
 
                     # Launch the job
                     create_job(job, device)
@@ -436,7 +457,7 @@ class Command(BaseCommand):
                         msg = "Infrastructure error: Invalid worker information"
                         self.logger.error("[%d] %s", job.id, msg)
                         fail_job(job, msg, TestJob.INCOMPLETE)
-                        return False
+                        return
                     self.logger.info("[%d] START => %s (%s) (retrying)", job.id,
                                      device.worker_host.hostname, device.hostname)
                     worker_host = device.worker_host
@@ -447,7 +468,7 @@ class Command(BaseCommand):
                 job_ctx = job_def.get('context', {})
 
                 # Load device configuration
-                device_configuration = None \
+                device_configuration = '' \
                     if job.dynamic_connection else device.load_device_configuration(job_ctx)
 
                 env_str = get_env_string(options['env'])
@@ -461,43 +482,45 @@ class Command(BaseCommand):
                             # FIXME: rationalise and streamline
                             self.controler.send_multipart(
                                 [str(worker_host.hostname),
-                                 'START', str(group_job.id), self.export_definition(group_job),
+                                 'START', str(group_job.id),
+                                 self.export_definition(group_job),
                                  str(device_configuration),
                                  env_str, env_dut_str])
 
                 self.controler.send_multipart(
                     [str(worker_host.hostname),
-                     'START', str(job.id), self.export_definition(job),
+                     'START', str(job.id),
+                     self.export_definition(job),
                      str(device_configuration),
                      env_str, env_dut_str])
+                return
 
-            except (jinja2.TemplateError, IOError, yaml.YAMLError) as exc:
-                if isinstance(exc, jinja2.TemplateNotFound):
-                    self.logger.error("Template not found: '%s'", exc.message)
-                    msg = "Infrastructure error: Template not found: '%s'" % \
-                          exc.message
-                elif isinstance(exc, jinja2.TemplateSyntaxError):
-                    self.logger.error("Template syntax error in '%s', line %d: %s",
-                                      exc.name, exc.lineno, exc.message)
-                    msg = "Infrastructure error: Template syntax error in '%s', line %d: %s" % \
-                          (exc.name, exc.lineno, exc.message)
-                elif isinstance(exc, IOError):
-                    self.logger.error("Unable to read '%s': %s",
-                                      options['env'], exc.strerror)
-                    msg = "Infrastructure error: cannot open '%s': %s" % \
-                          (options['env'], exc.strerror)
-                elif isinstance(exc, yaml.YAMLError):
-                    self.logger.error("Unable to parse job definition: %s",
-                                      exc)
-                    msg = "Infrastructure error: cannot parse job definition: %s" % \
-                          exc
-                else:
-                    self.logger.exception(exc)
-                    msg = "Infrastructure error: %s" % exc.message
+            except jinja2.TemplateNotFound as exc:
+                self.logger.error("[%d] Template not found: '%s'",
+                                  job.id, exc.message)
+                msg = "Infrastructure error: Template not found: '%s'" % \
+                      exc.message
+            except jinja2.TemplateSyntaxError as exc:
+                self.logger.error("[%d] Template syntax error in '%s', line %d: %s",
+                                  job.id, exc.name, exc.lineno, exc.message)
+                msg = "Infrastructure error: Template syntax error in '%s', line %d: %s" % \
+                      (exc.name, exc.lineno, exc.message)
+            except IOError as exc:
+                self.logger.error("[%d] Unable to read '%s': %s",
+                                  job.id, exc.filename, exc.strerror)
+                msg = "Infrastructure error: cannot open '%s': %s" % \
+                      (exc.filename, exc.strerror)
+            except yaml.YAMLError as exc:
+                self.logger.error("[%d] Unable to parse job definition: %s",
+                                  job.id, exc)
+                msg = "Infrastructure error: cannot parse job definition: %s" % \
+                      exc
+            else:
+                self.logger.exception(exc)
+                msg = "Infrastructure error: %s" % exc.message
 
-                self.logger.error("[%d] INCOMPLETE job", job.id)
-                fail_job(job=job, fail_msg=msg, job_status=TestJob.INCOMPLETE)
-        return True
+            self.logger.error("[%d] INCOMPLETE job", job.id)
+            fail_job(job=job, fail_msg=msg, job_status=TestJob.INCOMPLETE)
 
     def handle_canceling(self):
         for job in TestJob.objects.filter(status=TestJob.CANCELING, is_pipeline=True):
@@ -642,11 +665,10 @@ class Command(BaseCommand):
                 # CANCEL and START messages
                 if now - last_db_access > DB_LIMIT:
                     last_db_access = now
-                    # Dispatch jobs
+
                     # TODO: make this atomic
-                    # only pick up pipeline jobs with devices in Reserved state
-                    if not self.process_jobs(options):
-                        continue
+                    # Dispatch pipeline jobs with devices in Reserved state
+                    self.process_jobs(options)
 
                     # Handle canceling jobs
                     self.handle_canceling()
