@@ -115,6 +115,40 @@ class TestTemplates(unittest.TestCase):
                                             if item.endswith(','):
                                                 self.fail("%s ends with a comma" % item)
         self.assertEqual(depth, 8)
+        test_template = prepare_jinja_template('staging-qemu-01', data, system_path=self.system)
+        job_ctx = {}
+        rendered = test_template.render(**job_ctx)
+        template_dict = yaml.load(rendered)
+
+        self.assertIsNotNone(template_dict['actions']['boot']['methods']['ipxe']['nfs']['commands'])
+
+        self.assertIsNotNone(template_dict['timeouts']['connections']['bootloader-commands'])
+        self.assertEqual(template_dict['timeouts']['connections']['bootloader-commands']['minutes'], 5)
+
+        # uses default value from template
+        self.assertEqual(500, template_dict['character_delays']['boot'])
+
+        # override template in job context
+        job_ctx = {'boot_character_delay': 150}
+        rendered = test_template.render(**job_ctx)
+        template_dict = yaml.load(rendered)
+        self.assertEqual(150, template_dict['character_delays']['boot'])
+
+        # add device dictionary override
+        # overrides the template default
+        data += """{% set boot_character_delay = 400 %}"""
+        test_template = prepare_jinja_template('staging-qemu-01', data, system_path=self.system)
+        job_ctx = {}
+        rendered = test_template.render(**job_ctx)
+        template_dict = yaml.load(rendered)
+        self.assertEqual(400, template_dict['character_delays']['boot'])
+
+        # job context does not override device dictionary
+        job_ctx = {'boot_character_delay': 150}
+        rendered = test_template.render(**job_ctx)
+        template_dict = yaml.load(rendered)
+        self.assertNotEqual(150, template_dict['character_delays']['boot'])
+        self.assertEqual(400, template_dict['character_delays']['boot'])
 
     def test_beaglebone_black_template(self):
         self.assertTrue(self.validate_data('staging-x86-01', """{% extends 'beaglebone-black.jinja2' %}
@@ -166,6 +200,7 @@ class TestTemplates(unittest.TestCase):
         rendered = test_template.render()
         template_dict = yaml.load(rendered)
         self.assertIsNotNone(template_dict)
+        self.assertEqual(template_dict['device_path'], ['/dev/bus/usb/000'])
 
     def test_panda_template(self):
         data = """{% extends 'panda.jinja2' %}
@@ -174,7 +209,7 @@ class TestTemplates(unittest.TestCase):
 {% set power_off_command = '/usr/bin/pduclient --daemon staging-master --hostname pdu15 --command off --port 05' %}
 {% set power_on_command = '/usr/bin/pduclient --daemon staging-master --hostname pdu15 --command on --port 05' %}"""
         self.assertTrue(self.validate_data('staging-panda-01', data))
-        test_template = prepare_jinja_template('staging-panda-01', data, system_path=False)
+        test_template = prepare_jinja_template('staging-panda-01', data, system_path=self.system)
         rendered = test_template.render()
         template_dict = yaml.load(rendered)
         self.assertIn('u-boot-commands', template_dict['timeouts']['actions'])
@@ -333,5 +368,52 @@ class TestTemplates(unittest.TestCase):
         rendered = test_template.render(**context)
         template_dict = yaml.load(rendered)
         self.assertIn(
-            'set extraargs root=/dev/nfs rw nfsroot={NFS_SERVER_IP}:{NFSROOTFS},tcp,hard,intr intel_mmio=on mmio=on ip=eth0:dhcp',
+            'set extraargs root=/dev/nfs rw nfsroot={NFS_SERVER_IP}:{NFSROOTFS},tcp,hard,intr intel_mmio=on mmio=on ip=dhcp',
             template_dict['actions']['boot']['methods']['ipxe']['nfs']['commands'])
+
+    def test_extra_nfs_opts(self):
+        data = """{% extends 'panda.jinja2' %}
+{% set connection_command = 'telnet serial4 7012' %}
+{% set hard_reset_command = '/usr/bin/pduclient --daemon staging-master --hostname pdu15 --command reboot --port 05' %}
+{% set power_off_command = '/usr/bin/pduclient --daemon staging-master --hostname pdu15 --command off --port 05' %}
+{% set power_on_command = '/usr/bin/pduclient --daemon staging-master --hostname pdu15 --command on --port 05' %}"""
+        job_ctx = {}
+        test_template = prepare_jinja_template('staging-panda-01', data, system_path=self.system)
+        rendered = test_template.render(**job_ctx)
+        template_dict = yaml.load(rendered)
+        for line in template_dict['actions']['boot']['methods']['u-boot']['nfs']['commands']:
+            if line.startswith("setenv nfsargs"):
+                self.assertIn(',tcp,hard,intr ', line)
+        job_ctx = {'extra_nfsroot_args': ',nolock'}
+        test_template = prepare_jinja_template('staging-panda-01', data, system_path=self.system)
+        rendered = test_template.render(**job_ctx)
+        template_dict = yaml.load(rendered)
+        for line in template_dict['actions']['boot']['methods']['u-boot']['nfs']['commands']:
+            if line.startswith("setenv nfsargs"):
+                self.assertIn(',tcp,hard,intr,nolock ', line)
+
+    def test_juno_uboot_vland_template(self):
+        data = """{% extends 'juno-uboot.jinja2' %}
+{% set map = {'iface0': {'lngswitch03': 19}, 'iface1': {'lngswitch03': 8}} %}
+{% set hard_reset_command = '/usr/local/lab-scripts/snmp_pdu_control --hostname lngpdu01 --command reboot --port 19' %}
+{% set tags = {'iface0': [], 'iface1': ['RJ45', '10M', '100M']} %}
+{% set interfaces = ['iface0', 'iface1'] %}
+{% set device_mac = '90:59:af:5e:69:fd' %}
+{% set sysfs = {'iface0': '/sys/devices/platform/ocp/4a100000.ethernet/net/',
+'iface1': '/sys/devices/platform/ocp/47400000.usb/47401c00.usb/musb-hdrc.1.auto/usb1/1-1/1-1:1.0/net/'} %}
+{% set power_off_command = '/usr/local/lab-scripts/snmp_pdu_control --hostname lngpdu01 --command off --port 19' %}
+{% set mac_addr = {'iface0': '90:59:af:5e:69:fd', 'iface1': '00:e0:4c:53:44:58'} %}
+{% set power_on_command = '/usr/local/lab-scripts/snmp_pdu_control --hostname lngpdu01 --command on --port 19' %}
+{% set connection_command = 'telnet localhost 7333' %}
+{% set exclusive = 'True' %}"""
+        self.assertTrue(self.validate_data('staging-x86-01', data))
+        test_template = prepare_jinja_template('staging-qemu-01', data, system_path=self.system)
+        rendered = test_template.render()
+        template_dict = yaml.load(rendered)
+        self.assertIn('interfaces', template_dict['parameters'])
+        self.assertIn('iface0', template_dict['parameters']['interfaces'])
+        self.assertIn('port', template_dict['parameters']['interfaces']['iface0'])
+        self.assertIn('target', template_dict['parameters']['interfaces'])
+        self.assertIn('ip', template_dict['parameters']['interfaces']['target'])
+        self.assertIsNone(template_dict['parameters']['interfaces']['target']['ip'])
+        self.assertIsNotNone(template_dict['parameters']['interfaces']['target']['mac'])
