@@ -17,15 +17,11 @@
 # along with LAVA Scheduler.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
-import xmlrpclib
 
 from twisted.application.service import Service
-from twisted.internet import defer
 from twisted.internet.task import LoopingCall
 
-from lava_scheduler_app import utils
 from lava_scheduler_daemon.job import JobRunner, catchall_errback
-from lava_scheduler_daemon.worker import WorkerData
 
 
 class JobQueue(Service):
@@ -40,20 +36,6 @@ class JobQueue(Service):
         self._check_job_call.clock = reactor
 
     def _checkJobs(self):
-        # Update Worker Heartbeat
-        #
-        # NOTE: This will recide here till we finalize scheduler refactoring
-        #       and a separte module for worker specific daemon gets created.
-        self.logger.debug("Worker heartbeat")
-        worker = WorkerData()
-
-        # Record the scheduler tick (timestamp).
-        worker.record_master_scheduler_tick()
-
-        try:
-            worker.put_heartbeat_data()
-        except (xmlrpclib.Fault, xmlrpclib.ProtocolError) as err:
-            worker.logger.error("Heartbeat update failed!")
 
         self.logger.debug("Refreshing jobs")
         return self.source.getJobList().addCallback(
