@@ -36,10 +36,11 @@ the current page into context of where it "belongs".
 To use this system apply the @BreadCrumb(name, parent=parent_view,
 needs=['required', 'keywords']) decorator to your view function. To render
 breadcrumbs you can use the default template that is a part of
-"layout/content.html" template. Your context must include the bread_crumb_trail
-variable. To construct it call BreadCrumbTrail.leading_to(your_view_name, ...)
-passing any of  the keyword arguments specified in needs of your and any parent
-views (yes this is annoying).
+"layouts/content-bootstrap.html" template. Your context must include the
+bread_crumb_trail variable. To construct it call
+BreadCrumbTrail.leading_to(your_view_name, ...) passing any of  the keyword
+arguments specified in needs of your and any parent views (yes this is
+annoying).
 
 A mistake in pairing 'needs' to keywords passed to BreadCrumbTrail.leading_to()
 will result in logged warnings (either a name of the URL being not
@@ -62,8 +63,8 @@ class BreadCrumb(object):
 
         The name is the essential property creating the actual text visible on
         web pages. It may be a static string or a new-style python string
-        template. Parent allows one to construct a static brad crumb tree where
-        each crubm may have at most one parent. Needs, if specified, must be
+        template. Parent allows one to construct a static bread crumb tree where
+        each crumb may have at most one parent. Needs, if specified, must be
         an array of strings that denote identifiers required to resolve the URL
         of this bread crumb. The identifiers are obtained from the call
         BreadCrumbTrail.leading_to().
@@ -82,7 +83,7 @@ class BreadCrumb(object):
         Call method, used when decorating function-based views
 
         Id does not redefine the function (so is not a real decorator) but
-        instead stores the brad crumb object in the _bread_crumb attribute of
+        instead stores the bread crumb object in the _bread_crumb attribute of
         the function.
         """
         self.view = view
