@@ -147,7 +147,7 @@ BRANDING_URL = 'http://www.linaro.org'
 BRANDING_HEIGHT = "BRANDING_HEIGHT", 22
 BRANDING_WIDTH = "BRANDING_WIDTH", 22
 BRANDING_BUG_URL = "https://bugs.linaro.org/enter_bug.cgi?product=LAVA%20Framework"
-BRANDING_SOURCE_URL = "https://git.linaro.org/gitweb?s=lava%2Flava"
+BRANDING_SOURCE_URL = "https://git.linaro.org/lava"
 
 # Logging
 
